==> proc-10.1.23.tar.gz: proc/js/proc-decrypt-dialog.js <==
/**
 * @file
 * Protected Content dialog .
 */
(function($, Drupal, once, drupalSettings, window) {
  Drupal.behaviors.ProcDialogBehavior = {
    attach: function(context, settings) {
      once('procDialogProcessed', '.proc-attach-dialog', context).forEach(function(element) {
        let field_info = drupalSettings.proc[element.getAttribute('data-proc-field-name')];
        let element_href = element.getAttribute("href").replace(/^\//, '');
        let path_prefix = window.location.origin + drupalSettings.path.baseUrl + element_href;
        let path_suffix = "?proc_standalone_mode=FALSE&cache-password=" + field_info['settings']['proc_allow_password_caching'];
        path_suffix += "&proc_parent_id='" + document.querySelector("input[name^='" + element.getAttribute('data-proc-field-name') + "']").id + "'";
        path_suffix += "&proc_field_name='" + element.getAttribute('data-proc-field-name') + "'";
        path_suffix += "&field-input-mode=" + field_info['settings']['proc_field_input_mode'];
        path_suffix += "&field-decryption-mode=" + field_info['settings']['proc_field_decryption_mode'];
        path_suffix += "&trigger-fields=" + field_info['settings']['proc_trigger_format'];
        let proc_path = path_prefix + '/' + path_suffix;
        let ajaxSettings = {
          url: proc_path,
          dialogType: "dialog",
          dialog: { width: 400, classes: { "ui-dialog": "class-" +  element.getAttribute('data-proc-field-name')} },
        };

        let myAjaxObject = Drupal.ajax(ajaxSettings);
        $(element).on('click', function(event) {
          event.preventDefault();
          myAjaxObject.execute();
        });
      });
    },
  };
})(jQuery, Drupal, once, drupalSettings, window);

==> proc-10.1.24.tar.gz: proc/js/proc-decrypt-dialog.js <==
/**
 * @file
 * Protected Content dialog .
 */
(function($, Drupal, once, drupalSettings, window) {
  Drupal.behaviors.ProcDialogBehavior = {
    attach: function(context, settings) {
      once('procDialogProcessed', '.proc-attach-dialog', context).forEach(function(element) {

        let field_info = drupalSettings.proc[element.getAttribute('data-proc-field-name')];
        let element_href = element.getAttribute("href").replace(drupalSettings.path.baseUrl, '');
        let path_prefix = window.location.origin + drupalSettings.path.baseUrl + element_href;
        let path_suffix = "?proc_standalone_mode=FALSE&cache-password=" + field_info['settings']['proc_allow_password_caching'];
        path_suffix += "&proc_field_name='" + element.getAttribute('data-proc-field-name') + "'";
        path_suffix += "&field-input-mode=" + field_info['settings']['proc_field_input_mode'];
        path_suffix += "&field-decryption-mode=" + field_info['settings']['proc_field_decryption_mode'];
        path_suffix += "&trigger-fields=" + field_info['settings']['proc_trigger_format'];
        let proc_path = path_prefix + '/' + path_suffix;

        let ajaxSettings = {
          url: proc_path,
          dialogType: "dialog",
          dialog: { width: 400, classes: { "ui-dialog": "class-" +  element.getAttribute('data-proc-field-name')} },
        };

        let myAjaxObject = Drupal.ajax(ajaxSettings);
        $(element).on('click', function(event) {
          event.preventDefault();
          myAjaxObject.execute();
        });
      });
    },
  };
})(jQuery, Drupal, once, drupalSettings, window);
